@@ -73,6 +73,14 @@ BlueWizard::BlueWizard()
     BluezQt::InitManagerJob *initJob = m_manager->init();
     initJob->start();
     connect(initJob, &BluezQt::InitManagerJob::result, this, &BlueWizard::initJobResult);
+
+    // When Finished page is opened, close wizard automatically
+    connect(this, &QWizard::currentIdChanged, this, [this](int id) {
+        if (id == Success) {
+            done(QDialog::Accepted);
+        }
+    // Sending notification in SuccessPage is asynchronous, so this needs to be queued.
+    }, Qt::QueuedConnection);
 }
 
 BluezQt::DevicePtr BlueWizard::device() const
