@@ -39,10 +39,10 @@ class ConnectPage : public QWizardPage, Ui::Connect
     Q_OBJECT
 
 public:
-    explicit ConnectPage(BlueWizard *parent = 0);
+    explicit ConnectPage(BlueWizard *parent = nullptr);
 
-    int nextId() const Q_DECL_OVERRIDE;
-    void initializePage() Q_DECL_OVERRIDE;
+    int nextId() const override;
+    void initializePage() override;
 
 protected:
     QList<QWizard::WizardButton> wizardButtonsLayout() const;
