@@ -26,11 +26,8 @@
 #include <QSortFilterProxyModel>
 #include <QRegularExpressionValidator>
 
-#include <KIconLoader>
 #include <KMessageWidget>
 #include <KLocalizedString>
-#include <KPixmapSequence>
-#include <KPixmapSequenceOverlayPainter>
 
 #include <BluezQt/Manager>
 #include <BluezQt/Device>
@@ -121,6 +118,7 @@ DiscoverPage::DiscoverPage(BlueWizard *parent)
     deviceView->setModel(m_model);
 
     connect(deviceView->selectionModel(), &QItemSelectionModel::currentChanged, this, &DiscoverPage::indexSelected);
+    connect(deviceView, &QListView::doubleClicked, this, &DiscoverPage::itemDoubleClicked);
 }
 
 void DiscoverPage::initializePage()
@@ -233,6 +231,12 @@ void DiscoverPage::indexSelected(const QModelIndex &index)
     Q_EMIT completeChanged();
 }
 
+void DiscoverPage::itemDoubleClicked(const QModelIndex &index)
+{
+    indexSelected(index);
+    m_wizard->next();
+}
+
 void DiscoverPage::usableAdapterChanged(BluezQt::AdapterPtr adapter)
 {
     m_adapter = adapter;
